## dbt-adapters 1.22.2 - December 19, 2025

### Under the Hood

- Add an `expanded_data_type` field to support extra type info needed when altering a column type ([#1510](https://github.com/dbt-labs/dbt-adapters/issues/1510))
